import librosa
import numpy
import matplotlib.pyplot as plt

class Sound:
    def __init__(self, stream = None, sample_rate = 44100):
        self.sample_rate = sample_rate
        self.stream = stream if stream else numpy.zeros(sample_rate)
    @classmethod
    def load(cls, filename, sample_rate = 44100):
        y, sr = librosa.load(filename, sample_rate)
        return cls(y, sr) 

import librosa
x, sr = librosa.load('modi.mp3')

plt.figure(figsize=(14, 5))
librosa.display.waveplot(x, sr=sr)


import setuptools

with open("README.md", "r") as fh:
    long_description = fh.read()

setuptools.setup(
    name="rmidi",
    version="v0.0.10",
    # scripts = ['MIDI.py', 'mutils.py', 'rmidi.py', 'sound.py'],
    packages=['rmidi'],
    author="rushike",
    author_email="rushike.ab1@gmail.com",
    description="Math Sequence to MIDI",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/rushike/rmidipy",
    install_requires=['numpy'],
    # packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)